import type { IndexDefinition as _IndexDefinition } from 'mongodb-data-service';
import type { ThunkAction } from 'redux-thunk';
import type { AnyAction } from 'redux';
import type { RootState } from './index';
import type { HandleErrorAction } from './error';
import type { RefreshFinishedAction } from './is-refreshing';
export type SortColumn = keyof typeof sortColumnToProps;
export type SortDirection = 'asc' | 'desc';
declare const sortColumnToProps: {
    readonly 'Name and Definition': "name";
    readonly Type: "type";
    readonly Size: "size";
    readonly Usage: "usageCount";
    readonly Properties: "properties";
};
export type IndexDefinition = Omit<_IndexDefinition, 'type' | 'cardinality' | 'properties' | 'version'> & Partial<_IndexDefinition>;
export type IndexFieldsDefinition = _IndexDefinition['fields'];
export declare enum ActionTypes {
    LoadIndexes = "indexes/indexes/LOAD_INDEXES",
    SortIndexes = "indexes/indexes/SORT_INDEXES"
}
type LoadIndexesAction = {
    type: ActionTypes.LoadIndexes;
    indexes: IndexDefinition[];
};
export type SortIndexesAction = {
    type: ActionTypes.SortIndexes;
    indexes: IndexDefinition[];
    column: SortColumn;
    order: SortDirection;
};
type Actions = LoadIndexesAction | SortIndexesAction;
type State = IndexDefinition[];
export declare const INITIAL_STATE: State;
export default function reducer(state: State | undefined, action: Actions): State;
export declare const loadIndexes: (indexes: IndexDefinition[]) => LoadIndexesAction;
export declare const sortIndexes: (column: SortColumn, order: SortDirection) => ThunkAction<void, RootState, void, SortIndexesAction>;
export declare const fetchIndexes: () => ThunkAction<Promise<void>, RootState, void, LoadIndexesAction | RefreshFinishedAction | HandleErrorAction>;
export declare const dropFailedIndex: (id: string) => ThunkAction<void, RootState, void, AnyAction>;
export declare const hideIndex: (indexName: string) => ThunkAction<Promise<void>, RootState, void, AnyAction>;
export declare const unhideIndex: (indexName: string) => ThunkAction<Promise<void>, RootState, void, AnyAction>;
export {};
//# sourceMappingURL=indexes.d.ts.map